==> knative-model-4.6.0-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/SequenceSpecFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpec;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpecFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceSpecFluent<A extends SequenceSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplate instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec getChannelTemplate();
    public io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec buildChannelTemplate();
    public A withChannelTemplate(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec channelTemplate);
    public Boolean hasChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplateLike(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec item);
    public SequenceSpecFluent.ChannelTemplateNested<A> editChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplateLike(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec item);
    public ObjectReference getReply();
    public A withReply(ObjectReference reply);
    public Boolean hasReply();
    public A addToSteps(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public A setToSteps(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public A addToSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... items);
    public A addAllToEventingSteps(Collection<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> items);
    public A removeFromSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... items);
    public A removeAllFromEventingSteps(Collection<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> items);
    
/**
 * This method has been deprecated, please use method buildSteps instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> getSteps();
    public List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> buildSteps();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildStep(int index);
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildFirstStep();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildLastStep();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);
    public Boolean hasMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);
    public A withSteps(List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> steps);
    public A withSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... steps);
    public Boolean hasSteps();
    public SequenceSpecFluent.EventingStepsNested<A> addNewEventingStep();
    public SequenceSpecFluent.EventingStepsNested<A> addNewStepLike(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public SequenceSpecFluent.EventingStepsNested<A> setNewStepLike(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public SequenceSpecFluent.EventingStepsNested<A> editStep(int index);
    public SequenceSpecFluent.EventingStepsNested<A> editFirstStep();
    public SequenceSpecFluent.EventingStepsNested<A> editLastStep();
    public SequenceSpecFluent.EventingStepsNested<A> editMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);

    public interface ChannelTemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpecFluent<SequenceSpecFluent.ChannelTemplateNested<N>>{

        
    public N and();    public N endChannelTemplate();
}
    public interface EventingStepsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.v1alpha1.SubscriberSpecFluent<SequenceSpecFluent.EventingStepsNested<N>>{

        
    public N and();    public N endEventingStep();
}


}

==> knative-model-4.7.2-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/SequenceSpecFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpec;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder;
import io.fabric8.knative.eventing.v1alpha1.SubscriberSpecFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SequenceSpecFluent<A extends SequenceSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplate instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec getChannelTemplate();
    public io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec buildChannelTemplate();
    public A withChannelTemplate(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec channelTemplate);
    public Boolean hasChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplateLike(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec item);
    public SequenceSpecFluent.ChannelTemplateNested<A> editChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplateLike(io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpec item);
    public ObjectReference getReply();
    public A withReply(ObjectReference reply);
    public Boolean hasReply();
    public A addToSteps(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public A setToSteps(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public A addToSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... items);
    public A addAllToEventingSteps(Collection<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> items);
    public A removeFromSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... items);
    public A removeAllFromEventingSteps(Collection<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> items);
    public A removeMatchingFromEventingSteps(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSteps instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> getSteps();
    public List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> buildSteps();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildStep(int index);
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildFirstStep();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildLastStep();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);
    public Boolean hasMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);
    public A withSteps(List<io.fabric8.knative.eventing.v1alpha1.SubscriberSpec> steps);
    public A withSteps(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec... steps);
    public Boolean hasSteps();
    public SequenceSpecFluent.EventingStepsNested<A> addNewEventingStep();
    public SequenceSpecFluent.EventingStepsNested<A> addNewStepLike(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public SequenceSpecFluent.EventingStepsNested<A> setNewStepLike(int index,io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public SequenceSpecFluent.EventingStepsNested<A> editStep(int index);
    public SequenceSpecFluent.EventingStepsNested<A> editFirstStep();
    public SequenceSpecFluent.EventingStepsNested<A> editLastStep();
    public SequenceSpecFluent.EventingStepsNested<A> editMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.eventing.v1alpha1.SubscriberSpecBuilder> predicate);

    public interface ChannelTemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.messaging.v1alpha1.ChannelTemplateSpecFluent<SequenceSpecFluent.ChannelTemplateNested<N>>{

        
    public N and();    public N endChannelTemplate();
}
    public interface EventingStepsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.v1alpha1.SubscriberSpecFluent<SequenceSpecFluent.EventingStepsNested<N>>{

        
    public N and();    public N endEventingStep();
}


}
